@@ -10,3 +10,9 @@ from lightseq.training.ops.pytorch.transformer_decoder_layer import (
 from lightseq.training.ops.pytorch.transformer import LSTransformer
 from lightseq.training.ops.pytorch.cross_entropy_layer import LSCrossEntropyLayer
 from lightseq.training.ops.pytorch.adam import LSAdam
+from lightseq.training.ops.pytorch.export import (
+    export_ls_config,
+    export_ls_embedding,
+    export_ls_encoder,
+    export_ls_decoder,
+)
